==> okteta_0.25.5.orig.tar.xz: okteta-0.25.5/kasten/controllers/view/charsetconversion/charsetconversiontoolview.cpp <==
/*
    This file is part of the Okteta Kasten module, made within the KDE community.

    Copyright 2011 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#include "charsetconversiontoolview.h"

// tool
#include "charsetconversionview.h"
#include "charsetconversiontool.h"

namespace Kasten {

CharsetConversionToolView::CharsetConversionToolView(CharsetConversionTool* tool)
    : mWidget(new CharsetConversionView(tool))
{
}

CharsetConversionToolView::~CharsetConversionToolView()
{
    delete mWidget;
}

QWidget* CharsetConversionToolView::widget()    const { return mWidget; }
QString CharsetConversionToolView::title()      const { return mWidget->tool()->title(); }
AbstractTool* CharsetConversionToolView::tool() const { return mWidget->tool(); }

}

==> okteta_0.26.3.orig.tar.xz: okteta-0.26.3/kasten/controllers/view/charsetconversion/charsetconversiontoolview.cpp <==
/*
    This file is part of the Okteta Kasten module, made within the KDE community.

    Copyright 2011 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#include "charsetconversiontoolview.hpp"

// tool
#include "charsetconversionview.hpp"
#include "charsetconversiontool.hpp"

namespace Kasten {

CharsetConversionToolView::CharsetConversionToolView(CharsetConversionTool* tool)
    : mWidget(new CharsetConversionView(tool))
{
}

CharsetConversionToolView::~CharsetConversionToolView()
{
    delete mWidget;
}

QWidget* CharsetConversionToolView::widget()    const { return mWidget; }
QString CharsetConversionToolView::title()      const { return mWidget->tool()->title(); }
AbstractTool* CharsetConversionToolView::tool() const { return mWidget->tool(); }

}
